import sys
import snowballstemmer

def usage():
    print('''usage: %s [-l <language>] [-i <input file>] [-o <output file>] [-c <character encoding>] [-p[2]] [-h]

The input file consists of a list of words to be stemmed, one per
line. Words should be in lower case, but (for English) A-Z letters
are mapped to their a-z equivalents anyway. If omitted, stdin is
used.

If -c is given, the argument is the character encoding of the input
and output files.  If it is omitted, the UTF-8 encoding is used.

If -p is given the output file consists of each word of the input
file followed by \"->\" followed by its stemmed equivalent.
If -p2 is given the output file is a two column layout containing
the input words in the first column and the stemmed equivalents in
the second column.

Otherwise, the output file consists of the stemmed words, one per
line.

-h displays this help''' % sys.argv[0])

def main():
    pretty = 0
    input = ''
    output = ''
    encoding = 'utf_8'
    language = 'English'
    show_help = False
    argv = sys.argv[1:]
    while len(argv):
        arg = argv.pop(0)
        if arg == '-h':
            show_help = True
            break
        elif arg == "-p":
            pretty = 1
        elif arg == "-p2":
            pretty = 2
        elif arg == "-l":
            if len(argv) == 0:
                show_help = True
                break
            language = argv.pop(0)
        elif arg == "-i":
            if len(argv) == 0:
                show_help = True
                break
            input = argv.pop(0)
        elif arg == "-o":
            if len(argv) == 0:
                show_help = True
                break
            output = argv.pop(0)
        elif arg == "-c":
            if len(argv) == 0:
                show_help = True
                break
            encoding = argv.pop(0)
    if show_help:
        usage()
    else:
        stemmer = snowballstemmer.stemmer(language)
        if input != '':
            infile = open(input, "r", encoding=encoding)
        else:
            infile = sys.stdin
            # reconfigure() requires Python 3.7 so check existing encoding.
            if infile.encoding.lower() != encoding.lower():
                infile.reconfigure(encoding = encoding)
        if output != '':
                outfile = open(output, "w", encoding=encoding)
        else:
            outfile = sys.stdout
            if outfile.encoding.lower() != encoding.lower():
                outfile.reconfigure(encoding = encoding)
        stemming(stemmer, infile, outfile, pretty)
        outfile.close()
        infile.close()


def stemming(stemmer, infile, outfile, pretty):
    for original in infile.readlines():
        original = original.strip()
        # Convert only ASCII-letters to lowercase, to match C behavior
        original = ''.join(c.lower() if 'A' <= c <= 'Z' else c for c in original)
        stemmed = stemmer.stemWord(original)
        if pretty == 0:
            if stemmed != "":
                outfile.write(stemmed)
        elif pretty == 1:
            outfile.write(original, " -> ", stemmed)
        elif pretty == 2:
            outfile.write(original)
            if len(original) < 30:
                outfile.write(" " * (30 - len(original)))
            else:
                outfile.write("\n")
                outfile.write(" " * 30)
            outfile.write(stemmed)
        outfile.write('\n')

main()



#!/usr/bin/env python

from setuptools import setup
import re

SNOWBALL_VERSION = '3.1.0'

n_stemmers = 0

langs = []
variants = {}
with open('modules.txt') as fp:
    for line in fp.readlines():
        if len(line) <= 1 or line[0] == '#':
            continue
        if line[-1:] == '\n':
            line = line[:-1]
        tokens = re.split(r'\s+', line)
        if len(tokens) < 3:
            print("Bad modules.txt line: " + line)
            continue
        (name, encs, codes) = tokens[:3]
        if len(tokens) > 3:
            variant_of = tokens[3]
            if variant_of in variants:
                variants[variant_of].append(name)
            else:
                variants[variant_of] = [name]
        else:
            langs.append(name)
        n_stemmers += 1

desc = 'This package provides ' + str(n_stemmers) + ' stemmers for ' + \
    str(len(langs)) + ' languages generated from Snowball algorithms.'

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
]

for lang in langs:
    lang_titlecase = lang.title()
    # Only classifiers listed in https://pypi.org/classifiers/ are allowed
    # Remove them here or submit them to https://github.com/pypa/trove-classifiers
    if lang_titlecase != 'Sesotho':
        classifiers.append('Natural Language :: ' + lang_titlecase)

classifiers.extend([
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'Programming Language :: Python :: 3.12',
    'Programming Language :: Python :: 3.13',
    'Programming Language :: Python :: Implementation :: CPython',
    'Programming Language :: Python :: Implementation :: PyPy',
    'Topic :: Database',
    'Topic :: Internet :: WWW/HTTP :: Indexing/Search',
    'Topic :: Text Processing :: Indexing',
    'Topic :: Text Processing :: Linguistic'
])

setup(name='snowballstemmer',
      version=SNOWBALL_VERSION,
      description=desc,
      author='Snowball Developers',
      author_email='snowball-discuss@lists.tartarus.org',
      url='https://github.com/snowballstem/snowball',
      keywords="stemmer",
      license="BSD-3-Clause",
      packages=['snowballstemmer'],
      package_dir={"snowballstemmer": "src/snowballstemmer"},
      python_requires='>=3.3',
      classifiers = classifiers
)
